from setuptools import setup

setup(name='GB_dist',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['GB_dist'],
      author = 'Manish kumar thota',
      author_email = 'manish.thota1999@gmail.com',
      
      zip_safe=False)
